==> patch-2.3.5.0.zip: app/language/en/keywords.php <==
<?php

return array(
    'login' => 'Login',
    'submit' => 'Submit',
    'activity_history' => 'Activity History',
    'back_home' => 'Home',
    'createUser' => 'Create User',
    'reset_my_password' => 'Reset My Password',
    'enter_your' => 'Enter your',
    'username' => 'Username',
    'displayName' => 'Display Name',
    'location' => 'Location',
    'department' => 'Department',
    'backup_dashboard' => 'BluVault Dashboard',
    'sync_dashboard' => 'BluSync Dashboard',
    'enter' => 'Enter',
    'cloudName' => 'Parablu Installation name',
    'userName' => 'User Name',
    'userNameOrEmailId' => 'User Name or Email Id',
    'vss' => 'Volume Shadow Service',
    'email_address' => 'Email Address',
    'recovery_key' => 'Recovery Key',
    'is_first_login' => 'Is First Login',
    'legalHold' => 'Enable Legal Hold',
    'systemFolders' => 'Include System Folders',
    'remember_me' => 'Keep Me Signed in',
    'already_registered' => 'Already Registered ?',
    'account_type' => 'Account Type',
    'deviceConnected' => 'Device Connected',
    'restoreByDevice' => 'Restore By Device',
    'change_password' => 'Change Password',
    'account_status' => 'Account Status',
    'scheduleName' => 'Schedule Name',
    'usersConnected' => 'Users Connected',
    'share_activity_history' => 'Share Activity History',
    'schedules' => 'Schedules',
    'ccS' => 'Cloud Credentials',
    'scheduleStartTime' => 'Schedule Start Time',
    'Days' => 'Days',
    'fullBackupPeriod' => 'Full Backup Frequency',
    'selectADay' => 'Select a Day',
    'selectAHour' => 'Select an Hour',
    'compEnabled' => 'Enable Compression',
    'fullBackupOptions' => 'Full Backup Options',
    'daily' => 'Daily',
    'monthly' => 'Monthly',
    'weekly' => 'Weekly',
    'serverName' => 'Server Name',
    'serverBackup' => 'Server Backup',
    'memoryUtilization' => 'Maximum Permissible Memory Utilization for Agent',
    'cloudCredentials' => 'Cloud Credentials',
    'filters' => 'Filters',
    'filterName' => 'Filter Name',
    'backup_information' => 'Backup Information',
    'sync_information' => 'Sync Information',
    'device_information' => 'Device Information',
    'create_new_schedule' => 'Create New Schedule',
    'create_new_filter' => 'Create New Filter',
    'create_new_policy' => 'Create New Policy',
    'edit_new_policy' => 'Edit New Policy',
    'save_policy' => 'Save Policy',
    'cancel' => 'Cancel',
    'userNames' => 'User Names',
    'create_new_bluvault' => 'Create New Paracloud',
    'paracloudIPs'=> 'Paracloud IPs',
    'blukrypt_IpAddress' => 'Blukrypt IP Address',
    'blukryptType' => 'Blukrypt Type',
    'blukrypt' => 'Blukrypt',
    'bluvault' => 'Paraclouds',
    'listOfBluvaults' => 'List of Paraclouds',
    'listOfBlukrypts' => 'List of BluKrypts',
    'policyRefresh' => 'Policy Refresh Frequency (In Hours)',
    'change_policy' => 'Change Policy',
    'action' => 'Action',
    'status' => 'Status',
    'policyName' => 'Policy Name',
    'backupPolicyName' => 'Backup Policy Name',
    'syncPolicyName' => 'Sync Policy Name',
    'inclusionFilters' => 'Inclusion Filters',
    'exclusionFilters' => 'Exclusion Filters',
    'sizeHelpMessage' => 'Size includes the sizes of earlier file versions',
    'select' => 'Select',
    'maxPermissibleFileSize' => 'Maximum Permissible File Size',
    'perUserBackupStorageLimit' => 'Per User Backup Storage Limit',
    'dcmEnabled' => 'Device Certificate Management Enabled',
    'defaultFoldersBackup' => 'Default Folders to Backup',
    'machineMaxThreshold' => 'Machine Max Threshold',
    'cpuUtilization' => 'CPU Throttle Setting for Agent',
    'nwFromPGToCloud' => 'Network Throttle Setting from BluKrypt to Cloud',
    'nwFromClientToPG' => 'Network Throttle Setting from Client to BluKrypt',
    'incrementalFileTransfer' => 'Partial File Transfer',
    'fullBackupEnabled' => 'Enable Full Backup',
    'fullBackupStartDate' => 'Full Backup Date',
    'dedup' => 'Dedup',
    'global' => 'Global',
    'networkThrottling' => 'Network Throttling',
    'partialFileSize' => 'Minimum File Size to Enable Partial File Transfer',
    'fileChunkableSize' => 'Partial File Transfer Chunk Size',
    'filesCrawlLimit' => 'Number of simultaneous file crawl operations allowed',
    'privacyGateWay' => 'BluKrypt',
    'privacyGateWayHostNames' => 'Preferred Blukrypt Hostnames',
    'options' => 'Options',
    'osType' => 'Operating System Type',
    'operatingSystem' => 'Operating System',
    'maxVersions' => 'Maximum number of Versions Allowed',
    'scheduleNames' => 'Schedule Names',
    'admin' => 'Admin',
    'read_only_admin' => 'Read Only Admin',
    'user' => 'User',
    'sync_access' => 'Sync Access',
    'web_access' => 'Only Web Access',
    'miniCloudName' => 'MiniCloud',
    'manageMiniClouds' => 'Manage MiniClouds',
    'miniCloudDeleteConfirm' => 'Deleting MiniCloud will permanently remove all your files inside the folder. It may take some time depending upon the size of your MiniCloud. Do you really want to delete the selected MiniCloud?',
    'clientToBluKrypt' => 'Client To BluKrypt',
    'bluKryptToAzureBlob' => 'BluKrypt to Cloud',
    'save' => 'Save',
    'setThrottlingLimit' => 'Set Throttling Limit',
    'throttlingLimitList' => 'Throttling Limit List',
    'startTime' => 'Start Time',
    'endTime' => 'End Time',
    'speed' => 'Speed',
    'days' => 'Days',
    'speedInMbPS' => 'Speed in Mbps',
    'activate' => 'Active',
    'de_activate' => 'Deactivated',
    'share_enabled' => 'Send Notifications for Sharing a File',
    'epa_web_access' => 'End Point & Web Access',
    'account' => 'Account',
    'last_modified_time' => 'Last Modified Time',
    'sync' => 'Sync',
    'ad_authentication' => 'Active Directory Authentication',
    'external_storage' => 'External Storage',
    'backup' => 'Backup',
    'user_account' => 'User Account',
    'reports' => 'Reports',
    'files_list' => 'Files List',
    'backup_activity_history' => 'Backup Activity History',
    'policy_configuration' => 'Policy Configuration',
    'edit_your_profile' => 'Edit your Profile',
    'enabled' => 'Enabled',
    'disabled' => 'Disabled',
    'deleted' => 'Deleted',
    'edit_profile' => 'Edit Profile',
    'block' => 'Block',
    'blocked' => 'Blocked',
    'unblock' => 'UnBlock',
    'decoupled' => 'Decoupled',
    'delete' => 'Delete',
    'share' => 'Share',
    'name' => 'Name',
    'email' => 'Email',
    'logout' => 'Logout',
    'unlock' => 'Unlock',
    'inclusion_folder_name' => 'Inclusion Folder Path',
    'exclusion_folder_name' => 'Exclusion Folder Path',
    'user_inclusion_folders' => 'User Inclusion Folders',
    'user_exclusion_folders' => 'User Exclusion Folders',
    'policy_information' => 'Policy Information',
    'list_of_users' => 'List of Users',
    'list_of_devices' => 'List of Devices',
    'include' => 'Include',
    'exclude' => 'Exclude',
    'time' => 'Time',
    'version' => 'Version',
    'storage_place' => 'Storage Location',
    'password' => 'Password',
    'rePassword' => 'Re-Type Password',
    'inclusionFolderDelete' => 'Are you sure you want to stop backing up this folder?',
    'exclusionFolderDelete' => 'Are you sure you want to start backing up this folder?',
    'drag_drop_not_supported' => 'File Drag/Drop operations are not supported for this browser.',
    'blockConfirm'    => 'Are you sure you want to block the selected user?',
    'unBlockConfirm'    => 'Are you sure you want to un-block the selected user?',
    'deleteConfirm'    => 'Are you sure you want to delete the selected user?',
    'blockConfirmDevice'    => 'Are you sure you want to block the selected device?',
    'unBlockConfirmDevice'    => 'Are you sure you want to un-block the selected device?',
    'deleteConfirmDevice'    => 'Are you sure you want to delete the selected device?',
    'confirmDelete' => 'Are you sure you want to delete ',
    'confirmBlock' => 'Are you sure you want to block ',
    'confirmUnblock' => 'Are you sure you want to unblock ',
    'exclusionError'    => 'Please enter a valid folder path.  Please ensure that you\'re not adding a path that has already been entered.',
    'inclusionError'    => 'Please enter a valid folder path.  Please ensure that you\'re not adding a path that has already been entered.',
    'start_time' => 'Start Time',
    'end_time' => 'End Time',
    'attempted' => 'Attempted',
    'comments' => 'Comments',
    'scheduleTimeZone' => 'Schedule Time Zone',
    'success' => 'Success',
    'failed' => 'Failed',
    'monday' => 'Monday',
    'tuesday' => 'Tuesday',
    'wednesday' => 'Wednesday',
    'thursday' => 'Thursday',
    'friday' => 'Friday',
    'saturday' => 'Saturday',
    'sunday' => 'Sunday',
    'deviceName' => 'Device Name',
    'manageContainer' => 'Manage Containers',
    'userId' => 'User Id',
    'containerName' => 'Container Name',
    'overViewDate' => 'Overview Date',
    'backupJobType' => 'Backup Job Type',
    'containerType' => 'Container Type',
    'dbPort' => 'Database Port',
    'fileSource' => 'File Source/DB Home Path',
    'containerPolicy' => 'Container Policy',
    'userGroup' => 'User Group',
    'groupName' => 'Group Name',
    'dbPassword' => 'Database Password',
    'dbUserName' => 'Database UserName',
    'epaInstallationDate' => 'Endpoint Agent Installation Date',
    'firstBackupStartTime' => 'First Backup Start Time',
    'firstBackupEndTime' => 'First Backup End Time',
    'edit_policy' => 'Edit Policy',
    'lastBackupStartTime' => 'Last Backup Start Time',
    'lastSuccessfulBackup' => 'Last Successful Backup',
    'lastBackupStatus' => 'Last Backup Status',
    'totalStorageUtilized' => 'Total Storage Utilized',
    'percentageOfFilesBackedUp' => 'Percentage Of Files Backed Up',
    'device' => 'Device',
    'last_server_connection_time' => 'Last Server Connection Time',
    'restoredTime' => 'Restored Time',
    'filesRestored' => 'Files Restored',
    'syncPolicyName' => 'File Sync and Share Policy Name',
    'lastBackup' => 'Last Backup',
    'storageUsed' => 'Storage Used',
    'reason' => 'Reason',
    'file_name' => 'File Name',
    'file_path' => 'File Path',
    'syncEnableAutomatic' => 'Automatic Sync',
    'syncInterval' => 'Sync Interval',
    'shareEnabled' => 'Enable Share',
    'twoWayShareEnabled' => 'Two Way Share Enabled',
    'complexPasswordRequired' => 'Complex Password',
    'highSecureShareEnabled' => 'Highly Secure Share',
    'preventDownloadEnabled' => 'Allow Download',
    'contentIndexEnabled' => 'Content Indexing',
    'deDuplicationEnabled' => 'De-Duplication',
    'cacheUsedData' => 'Cache Frequently Used Data',
    'maxFileSize' => 'Maximum File Size',
    'userSizeAllowed' => 'Total Storage Size',
    'expiredDate' => 'Share Expiry Date Required',
    'go_backup' => 'Go Back to the Login Page',
    'file_size' => 'File Size',
    'priority' => 'PRIORITY',
    'nearest' => 'NEAREST',
    'UploadedSize' => 'Uploaded Size',
    'configuredBackupFolder' => 'Configured Backup Folder',
    'diskSpaceDetails' => 'Disk Space Details',
    'downloadAgent' => 'Download Agent',
    'partialFileAttributes' => 'Partial File Transfer Attributes',
    'networkThrottlingAttributes' => 'Network Throttling Attributes',
    'uISettingsForAgent' => 'UI Settings For Agent',
    'EXIT' => 'Exit',
    'DECOUPLE' => 'Decouple',
    'SUPPORT' => 'Support',
    'INTIATE_BACKUP' => 'Initiate Backup',
    'RESTORE' => 'Restore',
    'STOP_BACKUP' => 'Stop Backup',
    'BACKUP_SETTINGS' => 'Backup Settings',
    'BACKUP_FILES' => 'Backup Files',
    'REFRESH_BACKUP_POLICY' => 'Refresh Backup Policy',
    'INITIATE_SYNC' => 'Initiate Sync',
    'SYNC_SETTINGS' => 'Sync Settings',
    'SYNC_FILES' => 'Sync Files',
    'REFRESH_SYNC_POLICY' => 'Refresh Sync Policy',
    'SEARCH' => 'Search',
    'OPEN_SYNC_FOLDER' => 'Open Sync Folder',
    'progress' => 'Progress',
    'add_paracloud' => 'Add Paracloud',
    'add_blukrypt' => 'Add Blukrypt',
    'paracloud_IpAddress' => 'Paracloud IP Address',
    'addAd' => 'Add AD',
    'userDomainName' => 'User Domain Name',
    'addYourActiveDirectoryCredentials' => 'Add your Active Directory Credentials',
    'aDPassword' => 'AD Password',
    'aDBase' => 'AD Base',
    'aDUrl' => 'AD Url',
    'bluSync' => 'BluSync',
    'bluVault' => 'BluVault',
    'aDGroupName' => 'AD Group Name',
    'activeDirectoryCommonName' => 'Active Directory Common Name',
    'activeDirectoryProductType' => 'Active Directory Product Type',
    'activeDirectoryCredentials' => 'Active Directory Credentials',
    'new' => 'New',
    'old' => 'Old',
    'manageCloud' => 'Manage Cloud Credentials',
    'manageParacloudBlukrypt' => 'Manage Paracloud and Blukrypt',
    'manageActiveDirectory' => 'Manage Active Directory Credentials',
    'manageProxy'=> 'Manage Proxy Settings',
    'manageSSLEncryption' => 'Manage SSL Certificate and Encryption',
    'manageSmtp' => 'Manage SMTP Settings',
    'kbps' => 'Kbps',
    'mbps' => 'Mbps',
    'gbps' => 'Gbps',
    'supportId' => 'Support Id',
    'date' => 'Date',
    'last_loggedin_time' => 'Last Log In Time',
);

==> patch-2.3.7.9.zip: app/language/en/keywords.php <==
<?php

return array(
    'login' => 'Login',
    'submit' => 'Submit',
    'activity_history' => 'Activity History',
    'back_home' => 'Home',
    'createUser' => 'Create User',
    'reset_my_password' => 'Reset My Password',
    'enter_your' => 'Enter your',
    'username' => 'Username',
    'displayName' => 'Display Name',
    'location' => 'Location',
    'department' => 'Department',
    'backup_dashboard' => 'BluVault Dashboard',
    'sync_dashboard' => 'BluSync Dashboard',
    'enter' => 'Enter',
    'cloudName' => 'Parablu Installation name',
    'userName' => 'User Name',
    'userNameOrEmailId' => 'User Name or Email Id',
    'vss' => 'Volume Shadow Service',
    'email_address' => 'Email Address',
    'recovery_key' => 'Recovery Key',
    'is_first_login' => 'Is First Login',
    'legalHold' => 'Enable Legal Hold',
    'systemFolders' => 'Include System Folders',
    'remember_me' => 'Keep Me Signed in',
    'already_registered' => 'Already Registered ?',
    'account_type' => 'Account Type',
    'deviceConnected' => 'Device Connected',
    'restoreByDevice' => 'Restore By Device',
    'change_password' => 'Change Password',
    'account_status' => 'Account Status',
    'scheduleName' => 'Schedule Name',
    'usersConnected' => 'Users Connected',
    'share_activity_history' => 'Share Activity History',
    'schedules' => 'Schedules',
    'ccS' => 'Cloud Credentials',
    'scheduleStartTime' => 'Schedule Start Time',
    'Days' => 'Days',
    'fullBackupPeriod' => 'Full Backup Frequency',
    'selectADay' => 'Select a Day',
    'selectAHour' => 'Select an Hour',
    'compEnabled' => 'Enable Compression',
    'fullBackupOptions' => 'Full Backup Options',
    'daily' => 'Daily',
    'monthly' => 'Monthly',
    'weekly' => 'Weekly',
    'serverName' => 'Server Name',
    'serverBackup' => 'Server Backup',
    'memoryUtilization' => 'Maximum Permissible Memory Utilization for Agent',
    'cloudCredentials' => 'Cloud Credentials',
    'filters' => 'Filters',
    'filterName' => 'Filter Name',
    'backup_information' => 'Backup Information',
    'sync_information' => 'Sync Information',
    'device_information' => 'Device Information',
    'create_new_schedule' => 'Create New Schedule',
    'create_new_filter' => 'Create New Filter',
    'create_new_policy' => 'Create New Policy',
    'edit_new_policy' => 'Edit New Policy',
    'save_policy' => 'Save Policy',
    'cancel' => 'Cancel',
    'userNames' => 'User Names',
    'create_new_bluvault' => 'Create New Paracloud',
    'paracloudIPs'=> 'Paracloud IPs',
    'blukrypt_IpAddress' => 'Blukrypt IP Address',
    'blukryptType' => 'Blukrypt Type',
    'blukrypt' => 'Blukrypt',
    'bluvault' => 'Paraclouds',
    'listOfBluvaults' => 'List of Paraclouds',
    'listOfBlukrypts' => 'List of BluKrypts',
    'policyRefresh' => 'Policy Refresh Frequency (In Hours)',
    'change_policy' => 'Change Policy',
    'action' => 'Action',
    'status' => 'Status',
    'policyName' => 'Policy Name',
    'backupPolicyName' => 'Backup Policy Name',
    'syncPolicyName' => 'Sync Policy Name',
    'inclusionFilters' => 'Inclusion Filters',
    'exclusionFilters' => 'Exclusion Filters',
    'sizeHelpMessage' => 'Size includes the sizes of earlier file versions',
    'select' => 'Select',
    'maxPermissibleFileSize' => 'Maximum Permissible File Size',
    'perUserBackupStorageLimit' => 'Per Device Backup Storage Limit',
    'dcmEnabled' => 'Device Certificate Management Enabled',
    'defaultFoldersBackup' => 'Default Folders to Backup',
    'machineMaxThreshold' => 'Machine Max Threshold',
    'cpuUtilization' => 'CPU Throttle Setting for Agent',
    'nwFromPGToCloud' => 'Network Throttle Setting from BluKrypt to Cloud',
    'nwFromClientToPG' => 'Network Throttle Setting from Client to BluKrypt',
    'incrementalFileTransfer' => 'Partial File Transfer',
    'fullBackupEnabled' => 'Enable Full Backup',
    'fullBackupStartDate' => 'Full Backup Date',
    'dedup' => 'Dedup',
    'global' => 'Global',
    'networkThrottling' => 'Network Throttling',
    'partialFileSize' => 'Minimum File Size to Enable Partial File Transfer',
    'fileChunkableSize' => 'Partial File Transfer Chunk Size',
    'filesCrawlLimit' => 'Number of simultaneous file crawl operations allowed',
    'privacyGateWay' => 'BluKrypt',
    'privacyGateWayHostNames' => 'Preferred Blukrypt Hostnames',
    'options' => 'Options',
    'osType' => 'Operating System Type',
    'operatingSystem' => 'Operating System',
    'maxVersions' => 'Maximum number of Versions Allowed',
    'scheduleNames' => 'Schedule Names',
    'admin' => 'Admin',
    'read_only_admin' => 'Read Only Admin',
    'user' => 'User',
    'sync_access' => 'Sync Access',
    'web_access' => 'Only Web Access',
    'miniCloudName' => 'MiniCloud',
    'manageMiniClouds' => 'Manage MiniClouds',
    'miniCloudDeleteConfirm' => 'Deleting MiniCloud will permanently remove all your files inside the folder. It may take some time depending upon the size of your MiniCloud. Do you really want to delete the selected MiniCloud?',
    'clientToBluKrypt' => 'Client To BluKrypt',
    'bluKryptToAzureBlob' => 'BluKrypt to Cloud',
    'save' => 'Save',
    'setThrottlingLimit' => 'Set Throttling Limit',
    'throttlingLimitList' => 'Throttling Limit List',
    'startTime' => 'Start Time',
    'endTime' => 'End Time',
    'speed' => 'Speed',
    'days' => 'Days',
    'speedInMbPS' => 'Speed in Mbps',
    'activate' => 'Active',
    'de_activate' => 'Deactivated',
    'share_enabled' => 'Send Notifications for Sharing a File',
    'epa_web_access' => 'End Point & Web Access',
    'account' => 'Account',
    'last_modified_time' => 'Last Modified Time',
    'sync' => 'Sync',
    'ad_authentication' => 'Active Directory Authentication',
    'external_storage' => 'External Storage',
    'backup' => 'Backup',
    'user_account' => 'User Account',
    'reports' => 'Reports',
    'files_list' => 'Files List',
    'backup_activity_history' => 'Backup Activity History',
    'policy_configuration' => 'Policy Configuration',
    'edit_your_profile' => 'Edit your Profile',
    'enabled' => 'Enabled',
    'disabled' => 'Disabled',
    'deleted' => 'Deleted',
    'edit_profile' => 'Edit Profile',
    'block' => 'Block',
    'blocked' => 'Blocked',
    'unblock' => 'UnBlock',
    'decoupled' => 'Decoupled',
    'delete' => 'Delete',
    'share' => 'Share',
    'name' => 'Name',
    'email' => 'Email',
    'logout' => 'Logout',
    'unlock' => 'Unlock',
    'inclusion_folder_name' => 'Inclusion Folder Path',
    'exclusion_folder_name' => 'Exclusion Folder Path',
    'user_inclusion_folders' => 'User Inclusion Folders',
    'user_exclusion_folders' => 'User Exclusion Folders',
    'policy_information' => 'Policy Information',
    'list_of_users' => 'List of Users',
    'list_of_devices' => 'List of Devices',
    'include' => 'Include',
    'exclude' => 'Exclude',
    'time' => 'Time',
    'version' => 'Version',
    'storage_place' => 'Storage Location',
    'password' => 'Password',
    'rePassword' => 'Re-Type Password',
    'inclusionFolderDelete' => 'Are you sure you want to stop backing up this folder?',
    'exclusionFolderDelete' => 'Are you sure you want to start backing up this folder?',
    'drag_drop_not_supported' => 'File Drag/Drop operations are not supported for this browser.',
    'blockConfirm'    => 'Are you sure you want to block the selected user?',
    'unBlockConfirm'    => 'Are you sure you want to un-block the selected user?',
    'deleteConfirm'    => 'Are you sure you want to delete the selected user?',
    'blockConfirmDevice'    => 'Are you sure you want to block the selected device?',
    'unBlockConfirmDevice'    => 'Are you sure you want to un-block the selected device?',
    'deleteConfirmDevice'    => 'Are you sure you want to delete the selected device?',
    'confirmDelete' => 'Are you sure you want to delete ',
    'confirmBlock' => 'Are you sure you want to block ',
    'confirmUnblock' => 'Are you sure you want to unblock ',
    'exclusionError'    => 'Please enter a valid folder path.',
    'inclusionError'    => 'Please enter a valid folder path.',
    'start_time' => 'Start Time',
    'end_time' => 'End Time',
    'attempted' => 'Attempted',
    'comments' => 'Comments',
    'scheduleTimeZone' => 'Schedule Time Zone',
    'success' => 'Success',
    'failed' => 'Failed',
    'monday' => 'Monday',
    'tuesday' => 'Tuesday',
    'wednesday' => 'Wednesday',
    'thursday' => 'Thursday',
    'friday' => 'Friday',
    'saturday' => 'Saturday',
    'sunday' => 'Sunday',
    'deviceName' => 'Device Name',
    'manageContainer' => 'Manage Containers',
    'userId' => 'User Id',
    'containerName' => 'Container Name',
    'overViewDate' => 'Overview Date',
    'backupJobType' => 'Backup Job Type',
    'containerType' => 'Container Type',
    'dbPort' => 'Database Port',
    'fileSource' => 'File Source/DB Home Path',
    'containerPolicy' => 'Container Policy',
    'userGroup' => 'User Group',
    'groupName' => 'Group Name',
    'dbPassword' => 'Database Password',
    'dbUserName' => 'Database UserName',
    'epaInstallationDate' => 'Endpoint Agent Installation Date',
    'firstBackupStartTime' => 'First Backup Start Time',
    'firstBackupEndTime' => 'First Backup End Time',
    'edit_policy' => 'Edit Policy',
    'lastBackupStartTime' => 'Last Backup Start Time',
    'lastSuccessfulBackup' => 'Last Successful Backup',
    'lastBackupStatus' => 'Last Backup Status',
    'totalStorageUtilized' => 'Total Storage Utilized',
    'percentageOfFilesBackedUp' => 'Percentage Of Files Backed Up',
    'device' => 'Device',
    'last_server_connection_time' => 'Last Server Connection Time',
    'restoredTime' => 'Restored Time',
    'filesRestored' => 'Files Restored',
    'syncPolicyName' => 'File Sync and Share Policy Name',
    'lastBackup' => 'Last Backup',
    'storageUsed' => 'Storage Used',
    'reason' => 'Reason',
    'file_name' => 'File Name',
    'file_path' => 'File Path',
    'syncEnableAutomatic' => 'Automatic Sync',
    'syncInterval' => 'Sync Interval',
    'shareEnabled' => 'Enable Share',
    'twoWayShareEnabled' => 'Two Way Share Enabled',
    'complexPasswordRequired' => 'Complex Password',
    'highSecureShareEnabled' => 'Highly Secure Share',
    'preventDownloadEnabled' => 'Allow Download',
    'contentIndexEnabled' => 'Content Indexing',
    'deDuplicationEnabled' => 'De-Duplication',
    'cacheUsedData' => 'Cache Frequently Used Data',
    'maxFileSize' => 'Maximum File Size',
    'userSizeAllowed' => 'Total Storage Size',
    'expiredDate' => 'Share Expiry Date Required',
    'go_backup' => 'Go Back to the Login Page',
    'file_size' => 'File Size',
    'priority' => 'PRIORITY',
    'nearest' => 'NEAREST',
    'UploadedSize' => 'Uploaded Size',
    'configuredBackupFolder' => 'Configured Backup Folder',
    'diskSpaceDetails' => 'Disk Space Details',
    'downloadAgent' => 'Download Agent',
    'partialFileAttributes' => 'Partial File Transfer Attributes',
    'networkThrottlingAttributes' => 'Network Throttling Attributes',
    'uISettingsForAgent' => 'UI Settings For Agent',
    'EXIT' => 'Exit',
    'DECOUPLE' => 'Decouple',
    'SUPPORT' => 'Support',
    'INTIATE_BACKUP' => 'Initiate Backup',
    'RESTORE' => 'Restore',
    'STOP_BACKUP' => 'Stop Backup',
    'BACKUP_SETTINGS' => 'Backup Settings',
    'BACKUP_FILES' => 'Backup Files',
    'REFRESH_BACKUP_POLICY' => 'Refresh Backup Policy',
    'INITIATE_SYNC' => 'Initiate Sync',
    'SYNC_SETTINGS' => 'Sync Settings',
    'SYNC_FILES' => 'Sync Files',
    'REFRESH_SYNC_POLICY' => 'Refresh Sync Policy',
    'SEARCH' => 'Search',
    'OPEN_SYNC_FOLDER' => 'Open Sync Folder',
    'progress' => 'Progress',
    'add_paracloud' => 'Add Paracloud',
    'add_blukrypt' => 'Add Blukrypt',
    'paracloud_IpAddress' => 'Paracloud IP Address',
    'addAd' => 'Add AD',
    'userDomainName' => 'User Domain Name',
    'addYourActiveDirectoryCredentials' => 'Add your Active Directory Credentials',
    'aDPassword' => 'AD Password',
    'aDBase' => 'AD Base',
    'aDUrl' => 'AD Url',
    'bluSync' => 'BluSync',
    'bluVault' => 'BluVault',
    'aDGroupName' => 'AD Group Name',
    'activeDirectoryCommonName' => 'Active Directory Common Name',
    'activeDirectoryProductType' => 'Active Directory Product Type',
    'activeDirectoryCredentials' => 'Active Directory Credentials',
    'new' => 'New',
    'old' => 'Old',
    'manageCloud' => 'Manage Cloud Credentials',
    'manageParacloudBlukrypt' => 'Manage Paracloud and Blukrypt',
    'manageActiveDirectory' => 'Manage Active Directory Credentials',
    'manageProxy'=> 'Manage Proxy Settings',
    'manageSSLEncryption' => 'Manage SSL Certificate and Encryption',
    'manageSmtp' => 'Manage SMTP Settings',
    'kbps' => 'Kbps',
    'mbps' => 'Mbps',
    'gbps' => 'Gbps',
    'supportId' => 'Support Id',
    'date' => 'Date',
    'last_loggedin_time' => 'Last Log In Time',
    'BLOCK_NOTIFICATIONS' => 'Block Notifications',
    'lastHeardTime' => 'Last Heard Time',
    'isFirstBackupCompleted' => 'Is First BackupCompleted',
    'lastSuccessfulBackupStartTime' => 'Last Successful Backup Start Time',
    'lastSuccessfulBackupEndTime' => 'Last Successful Backup End Time',
    'currentBackupStartTime' => 'Current Backup Start Time',
    'currentBackupStatus' => 'Current Backup Status',
    'currentBackupCompletionPercentage' => 'Current Backup Completion Percentage',
    'clientIdForLogin' => 'Client Id For Login',
     'clientIdForAADSync' => 'Client Id For AAD Sync',
     'clientSecretKey' => 'Client Secret Key',
     'redirectURI' => 'Redirect URI',
     'addYourAzureActiveDirectoryCredentials' => 'Add your Azure Active Directory Credentials',
     'addAAd' => 'Add AAD',
     'aadGroupName' => 'AAD Group Name',
     'azureActiveDirectoryCommonName' => 'Azure Active Directory Common Name',
     'azureActiveDirectoryProductType' => 'Azure Active Directory Product Type',
     'azureActiveDirectoryCredentials' => 'Azure Active Directory Credentials',
     'aadCredentials' => 'Azure Active Directory Credentials',
);
